"""Version and details for pcraft"""

__description__ = "Pcraft"
__url__ = "https://www.github.com/devoinc/pcraft"
__version__ = "0.0.7"
__author__ = "Sebastien Tricaud"
__author_email__ = "sebastien.tricaud@devo.com"
__license__ = "MIT"
__maintainer__ = __author__
__maintainer_email__ = __author_email__
